#!/usr/bin/env python

"""Tests for `mc_transformers` package."""


import unittest

from mc_transformers import mc_transformers  # noqa: F401


class TestMc_transformers(unittest.TestCase):
    """Tests for `mc_transformers` package."""

    def setUp(self):
        """Set up test fixtures, if any."""

    def tearDown(self):
        """Tear down test fixtures, if any."""

    def test_000_something(self):
        """Test something."""
